@@ -248,8 +248,11 @@ static double quality_to_mse(long quality)
 static unsigned int mse_to_quality(double mse)
 {
     int i;
+    /* Allow for floating point errors. */
+    double eps = 0.00001;
     for(i=100; i > 0; i--) {
-        if (mse <= quality_to_mse(i)) {
+	printf ("%g %g\n", mse, quality_to_mse (i));
+        if (mse <= quality_to_mse(i) + eps) {
             return i;
         }
     }
@@ -479,8 +482,12 @@ LIQ_EXPORT liq_attr* liq_attr_create_with_allocator(void* (*custom_malloc)(size_
     }
 #endif
     if (!custom_malloc && !custom_free) {
+        custom_malloc = malloc;
+        custom_free = free;
+	/*
         custom_malloc = liq_aligned_malloc;
         custom_free = liq_aligned_free;
+	*/
     } else if (!custom_malloc != !custom_free) {
         return NULL; // either specify both or none
     }
